pub struct SerdeValueError(pub String);Expand description
Error type used when converting between Value and serde types.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Debug for SerdeValueError
impl Debug for SerdeValueError
Sourceimpl Display for SerdeValueError
impl Display for SerdeValueError
Sourceimpl Error for SerdeValueError
impl Error for SerdeValueError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
Sourceimpl Error for SerdeValueError
impl Error for SerdeValueError
Sourceimpl Error for SerdeValueError
impl Error for SerdeValueError
Sourcefn custom<T>(msg: T) -> SerdeValueErrorwhere
T: Display,
fn custom<T>(msg: T) -> SerdeValueErrorwhere
T: Display,
Raised when there is general error when deserializing a type. Read more
Sourcefn invalid_type(unexp: Unexpected<'_>, exp: &dyn Expected) -> Self
fn invalid_type(unexp: Unexpected<'_>, exp: &dyn Expected) -> Self
Raised when a
Deserialize receives a type different from what it was
expecting. Read moreSourcefn invalid_value(unexp: Unexpected<'_>, exp: &dyn Expected) -> Self
fn invalid_value(unexp: Unexpected<'_>, exp: &dyn Expected) -> Self
Raised when a
Deserialize receives a value of the right type but that
is wrong for some other reason. Read moreSourcefn invalid_length(len: usize, exp: &dyn Expected) -> Self
fn invalid_length(len: usize, exp: &dyn Expected) -> Self
Raised when deserializing a sequence or map and the input data contains
too many or too few elements. Read more
Sourcefn unknown_variant(variant: &str, expected: &'static [&'static str]) -> Self
fn unknown_variant(variant: &str, expected: &'static [&'static str]) -> Self
Raised when a
Deserialize enum type received a variant with an
unrecognized name.Sourcefn unknown_field(field: &str, expected: &'static [&'static str]) -> Self
fn unknown_field(field: &str, expected: &'static [&'static str]) -> Self
Raised when a
Deserialize struct type received a field with an
unrecognized name.Sourcefn missing_field(field: &'static str) -> Self
fn missing_field(field: &'static str) -> Self
Raised when a
Deserialize struct type expected to receive a required
field with a particular name but that field was not present in the
input.Sourcefn duplicate_field(field: &'static str) -> Self
fn duplicate_field(field: &'static str) -> Self
Raised when a
Deserialize struct type received more than one of the
same field.Auto Trait Implementations
impl Freeze for SerdeValueError
impl RefUnwindSafe for SerdeValueError
impl Send for SerdeValueError
impl Sync for SerdeValueError
impl Unpin for SerdeValueError
impl UnwindSafe for SerdeValueError